@@ -17,12 +17,13 @@ def check_status_code(replayed):
 
 def check_diff_responses():
     for i in play.Replayed.responses:
-        if i['uri'] in play.Replayed.config:
+        paths = play.Replayed.config['path']
+        if i['uri'] in paths:
             old = i['old']
             new = i['new']
-            if play.Replayed.config[i['uri']]:
-                old = _filter(old, filters=play.Replayed.config[i['uri']])
-                new = _filter(new, filters=play.Replayed.config[i['uri']])
+            if paths[i['uri']]:
+                old = _filter(old, filters=paths[i['uri']])
+                new = _filter(new, filters=paths[i['uri']])
             result = DeepDiff(old, new, ignore_order=True)
             print(result)
             if result.get('values_changed'):
